@@ -1,10 +1,10 @@
 package DBM::Deep::Engine;
 
-use 5.6.0;
+use 5.006_000;
 
 use strict;
 
-our $VERSION = q(0.99_03);
+our $VERSION = q(0.99_04);
 
 use Scalar::Util ();
 
