@@ -1,6 +1,6 @@
 package t::common;
 
-use 5.6.0;
+use 5.006_000;
 
 use strict;
 use warnings;
